# Command line interface (CLI)

The CLI is invoked by typing:

:::{code-block} pwsh
glopan
:::

or

:::{code-block} pwsh
python -m glopan
:::

The CLI is documented below.

::::{eval-rst}
.. click:: glopan.cli:typer_click_object
   :prog: glopan
   :nested: full
::::
